import { SendButton } from './SendButton';
import { SwatchPicker } from './SwatchPicker';
import React, { useEffect, useMemo, useRef, useState } from 'react';
import { createBoard, encodeBoardCharactersAsync } from '../utils';
import { fontFamily, responsive } from '../theme';
import { BoardEditorPreview } from './BoardEditorPreview';
import Box from '@mui/material/Box';
import ButtonBase from '@mui/material/ButtonBase';
import Menu from '@mui/material/Menu';
import MenuItem from '@mui/material/MenuItem';
import RedoIcon from '@mui/icons-material/Redo';
import { Spacer } from './Spacer';
import UndoIcon from '@mui/icons-material/Undo';
import { WysiwygEditor } from './WysiwygEditor';
import { getIcon } from '../utils/getIcon';
import { makeVestaboardStyles } from '../hooks/useVestaboardStyles';
import useMediaQuery from '@mui/material/useMediaQuery';
var useStyles = makeVestaboardStyles(function () {
    var _a, _b, _c, _d, _e, _f, _g;
    return ({
        wrapperContainer: (_a = {},
            _a["@media(max-width: ".concat(responsive.MOBILE, "px)")] = {
                justifyContent: 'space-between',
                flex: 1,
                display: 'flex',
                flexDirection: 'column',
            },
            _a),
        topRow: (_b = {
                display: 'flex',
                justifyContent: 'space-between',
                paddingBottom: '29px'
            },
            _b["@media(max-width: ".concat(responsive.MOBILE, "px)")] = {
                padding: '0px 14px',
            },
            _b),
        viewButtons: {
            display: 'flex',
        },
        modeButton: {
            color: '#f5f5f7',
            fontSize: 16,
            opacity: 0.5,
        },
        modeButtonOn: {
            color: '#f5f5f7',
            fontSize: 16,
            opacity: 1,
        },
        modeButtonIcon: {
            height: 19,
            marginLeft: 12,
        },
        actionButtons: {
            display: 'flex',
        },
        undoIcon: {
            color: '#f5f5f7',
            opacity: 0.7,
        },
        textAreaSpace: (_c = {
                height: 107
            },
            _c["@media(max-width: ".concat(responsive.MOBILE, "px)")] = {
                height: 0,
                display: 'none',
            },
            _c),
        textAreaOnSpace: (_d = {
                height: 25
            },
            _d["@media(max-width: ".concat(responsive.MOBILE, "px)")] = {
                height: 0,
                display: 'none',
            },
            _d),
        bottomActions: (_e = {
                display: 'flex',
                justifyContent: 'space-between',
                alignItems: 'center',
                marginTop: '18px'
            },
            _e["@media(max-width: ".concat(responsive.MOBILE, "px)")] = {
                flexDirection: 'column-reverse',
            },
            _e),
        bottomActionButtons: (_f = {
                display: 'flex',
                justifyContent: 'space-between',
                flex: 1,
                paddingLeft: '29px'
            },
            _f["@media(max-width: ".concat(responsive.MOBILE, "px)")] = {
                paddingLeft: 0,
                width: 'calc(100vw - 60px)',
                left: '14px',
            },
            _f),
        bottomActionButton: {
            color: '#f5f5f7',
            fontSize: 16,
        },
        editorArea: (_g = {},
            _g["@media(max-width: ".concat(responsive.MOBILE, "px)")] = {
                display: 'flex',
                flexDirection: 'column',
                justifyContent: 'center',
                padding: '0px 14px',
            },
            _g),
        textareaBackground: {
            backgroundColor: '#1F2123',
            padding: '14px 18px',
            position: 'relative',
        },
        textarea: {
            background: 'transparent',
            border: 'none',
            width: '100%',
            color: '#f5f5f7',
            outline: 0,
            fontFamily: fontFamily.default,
            fontSize: 16,
            lineHeight: '1.5rem',
            resize: 'none',
            borderRadius: '8px',
        },
        countdown: {
            opacity: '0.31',
            fontSize: 12,
            color: '#FFF',
            fontFamily: fontFamily.default,
            position: 'absolute',
            right: 18,
            bottom: 14,
        },
    });
});
export var BoardEditor = function (props) {
    var _a = useState(false), showPreview = _a[0], setShowPreview = _a[1];
    var _b = useState(false), isPaintMode = _b[0], setIsPaintMode = _b[1];
    var _c = useState(0), color = _c[0], setColor = _c[1];
    var _d = useState(false), animated = _d[0], setAnimated = _d[1];
    var _e = useState(props.mode || 'display'), mode = _e[0], setMode = _e[1];
    var _f = useState(''), value = _f[0], setValue = _f[1];
    var styles = useStyles();
    var classes = useMemo(function () { return styles; }, []);
    var historyRef = useRef([]);
    var historyPositionRef = useRef(0);
    var _g = useState(null), anchorEl = _g[0], setAnchorEl = _g[1];
    var isMobile = useMediaQuery("(max-width: ".concat(responsive.MOBILE, "px)"));
    var previousRef = useRef('');
    useEffect(function () {
        if (previousRef.current !== value) {
            encodeBoardCharactersAsync({
                message: value,
                columns: props.columns,
                rows: props.rows,
            }).then(props.setBoardValue);
        }
        previousRef.current = value;
    }, [value, props.setBoardValue]);
    var handleOpenDrafts = function (event) {
        setAnchorEl(event.currentTarget);
    };
    var handleCloseDrafts = function () {
        setAnchorEl(null);
    };
    return (React.createElement(Box, { sx: classes.wrapperContainer },
        React.createElement(Box, { sx: classes.topRow },
            React.createElement(Box, { sx: classes.viewButtons },
                React.createElement(ButtonBase, { sx: mode === 'display' ? classes.modeButtonOn : classes.modeButton, onClick: function () {
                        setMode('display');
                    } },
                    "Auto",
                    ' ',
                    React.createElement("img", { style: classes.modeButtonIcon, src: getIcon('autoicon-on') })),
                React.createElement(Spacer, { size: "large", horizontal: true }),
                React.createElement(ButtonBase, { sx: mode === 'type' ? classes.modeButtonOn : classes.modeButton, onClick: function () {
                        setMode('type');
                    } },
                    "Visual",
                    ' ',
                    React.createElement("img", { style: classes.modeButtonIcon, src: getIcon('visual-on') }))),
            React.createElement(Box, { sx: classes.actionButtons },
                !isMobile && mode !== 'type' && (React.createElement(ButtonBase, { sx: classes.modeButton, onClick: function () {
                        setAnimated(!animated);
                    } },
                    "Animation ",
                    animated ? 'ON' : 'OFF')),
                React.createElement(Spacer, { size: "large", horizontal: true }),
                props.onTemplatesClick && (React.createElement(React.Fragment, null,
                    React.createElement(ButtonBase, { sx: classes.modeButtonOn, onClick: function () {
                            props.onTemplatesClick && props.onTemplatesClick();
                        } }, "Templates"),
                    React.createElement(Spacer, { size: "large", horizontal: true }))),
                React.createElement(ButtonBase, { sx: classes.modeButtonOn, onClick: function () {
                        setValue('');
                        var value = createBoard({
                            columns: props.columns,
                            rows: props.rows,
                        });
                        props.setBoardValue(value);
                        historyRef.current[historyPositionRef.current] = value;
                        historyPositionRef.current = historyPositionRef.current + 1;
                    } }, "Clear"),
                mode === 'type' && (React.createElement(React.Fragment, null,
                    React.createElement(Spacer, { size: "large", horizontal: true }),
                    React.createElement(ButtonBase, { title: "Undo", onClick: function () {
                            if (!historyPositionRef.current) {
                                return;
                            }
                            historyPositionRef.current = historyPositionRef.current - 1;
                            var value = historyRef.current[historyPositionRef.current - 1];
                            props.setBoardValue(value ||
                                createBoard({
                                    columns: props.columns,
                                    rows: props.rows,
                                }));
                        } },
                        React.createElement(UndoIcon, { sx: classes.undoIcon })),
                    React.createElement(Spacer, { size: "small", horizontal: true }),
                    React.createElement(ButtonBase, { title: "Redo", onClick: function () {
                            var value = historyRef.current[historyPositionRef.current];
                            historyPositionRef.current = historyPositionRef.current + 1;
                            if (value) {
                                props.setBoardValue(value);
                            }
                        } },
                        React.createElement(RedoIcon, { sx: classes.undoIcon })))))),
        React.createElement(Box, { sx: classes.editorArea },
            !isMobile || mode !== 'display' ? (React.createElement(WysiwygEditor, { value: props.boardValue, setValue: function (value) {
                    props.setBoardValue(value);
                    historyRef.current[historyPositionRef.current] = value;
                    historyPositionRef.current = historyPositionRef.current + 1;
                }, mode: isPaintMode ? 'paint' : mode, animated: animated, color: color, boardStyle: props.boardStyle, columns: props.columns, rows: props.rows })) : null,
            React.createElement(Spacer, { size: "small" }),
            mode === 'display' ? (React.createElement(Box, null,
                React.createElement(Box, { sx: classes.textAreaOnSpace }),
                React.createElement(Box, { sx: classes.textareaBackground },
                    React.createElement("textarea", { style: classes.textarea, value: value, onChange: function (e) {
                            if (e.target.value.includes('[[') &&
                                e.target.value.includes(']]')) {
                                try {
                                    var json = JSON.parse(e.target.value);
                                    props.setBoardValue(json);
                                    historyRef.current[historyPositionRef.current] = json;
                                    historyPositionRef.current =
                                        historyPositionRef.current + 1;
                                    setMode('paint');
                                }
                                catch (err) {
                                    setValue(e.target.value);
                                }
                            }
                            else {
                                setValue(e.target.value);
                            }
                        }, rows: 3, placeholder: "Type here for auto-arrangement or click Visual above to control placement." }),
                    React.createElement(Box, { sx: classes.countdown }, 132 - value.length)))) : (React.createElement(Box, { sx: classes.textAreaSpace }))),
        React.createElement(Box, { sx: classes.bottomActions },
            React.createElement(SwatchPicker, { value: color, isPaintMode: isPaintMode, setValue: function (color) {
                    setColor(color);
                    setIsPaintMode(true);
                    setMode('type');
                }, endPaintMode: function () {
                    setIsPaintMode(false);
                }, showFilledColor: props.showFilledColor }),
            React.createElement(Box, { sx: classes.bottomActionButtons },
                isMobile && props.onCancel ? (React.createElement(ButtonBase, { sx: classes.bottomActionButton, onClick: props.onCancel }, "Cancel")) : null,
                props.onSaveDraft && props.onSelectDraft ? (React.createElement(React.Fragment, null,
                    React.createElement(ButtonBase, { sx: classes.bottomActionButton, onClick: handleOpenDrafts }, "Drafts"),
                    React.createElement(Menu, { keepMounted: true, onClose: handleCloseDrafts, anchorEl: anchorEl, open: Boolean(anchorEl) },
                        React.createElement(MenuItem, { onClick: function () {
                                if (props.onSaveDraft) {
                                    props.onSaveDraft();
                                }
                                handleCloseDrafts();
                            } }, "Save"),
                        React.createElement(MenuItem, { onClick: function () {
                                if (props.onSelectDraft) {
                                    props.onSelectDraft();
                                    setMode('type');
                                }
                                handleCloseDrafts();
                            } }, "Load")))) : null,
                isMobile && (React.createElement(ButtonBase, { sx: classes.bottomActionButton, onClick: function () { return setShowPreview(true); } }, "Preview")),
                props.onSend ? (React.createElement(SendButton, { dropdownActions: props.dropdownActions, onSend: props.onSend, onSchedule: props.onSchedule, buttonLabel: props.sendButtonLabel })) : null)),
        showPreview && (React.createElement(BoardEditorPreview, { boardValue: props.boardValue, onClose: function () {
                setShowPreview(false);
            }, onSend: props.onSend
                ? function () {
                    setShowPreview(false);
                    if (props.onSend) {
                        props.onSend();
                    }
                }
                : undefined, onSchedule: props.onSchedule
                ? function () {
                    setShowPreview(false);
                    if (props.onSchedule) {
                        props.onSchedule();
                    }
                }
                : undefined, onSaveDraft: props.onSaveDraft
                ? function () {
                    setShowPreview(false);
                    if (props.onSaveDraft) {
                        props.onSaveDraft();
                    }
                }
                : undefined, onSelectDraft: props.onSelectDraft
                ? function () {
                    setShowPreview(false);
                    if (props.onSelectDraft) {
                        props.onSelectDraft();
                        setMode('type');
                    }
                }
                : undefined }))));
};
