import React, { useState } from 'react';
import Box from '@mui/material/Box';
import ButtonBase from '@mui/material/ButtonBase';
import Menu from '@mui/material/Menu';
import MenuItem from '@mui/material/MenuItem';
import ReplayIcon from '@mui/icons-material/Replay';
import { SendButton } from './SendButton';
import { WysiwygEditor } from './WysiwygEditor';
import { createBoard } from '../utils';
import { getIcon } from '../utils/getIcon';
import { makeVestaboardStyles } from '../hooks/useVestaboardStyles';
var useStyles = makeVestaboardStyles({
    container: {
        position: 'fixed',
        top: 0,
        left: 0,
        width: '100vw',
        height: '100vh',
        backdropFilter: 'blur(6px)',
        backgroundColor: 'rgba(10, 10, 11, 0.9)',
        zIndex: 10000,
        overflow: 'hidden',
    },
    containerInner: {
        position: 'relative',
        height: '100%',
        width: '100%',
        display: 'flex',
        flexDirection: 'row',
        alignItems: 'center',
    },
    close: {
        position: 'absolute',
        top: 28,
        right: 22,
    },
    boardContainer: {
        margin: 22,
        width: 'calc(100% - 44px)',
    },
    bottomActionButtons: {
        display: 'flex',
        justifyContent: 'space-between',
        flex: 1,
        paddingLeft: 22,
        position: 'fixed',
        bottom: 22,
        width: 'calc(100vw - 44px)',
    },
    bottomActionButton: {
        color: '#f5f5f7',
        fontSize: 16,
    },
    animateButton: {
        width: '100%',
        marginBottom: 22,
        display: 'flex',
        justifyContent: 'flex-end',
    },
    modeButton: {
        color: '#f5f5f7',
        fontSize: 16,
        opacity: 0.5,
    },
    replay: {
        width: '100%',
        marginTop: 22,
        display: 'flex',
        justifyContent: 'center',
    },
    replayButton: {
        color: '#f5f5f7',
        opacity: 0.3,
        width: 20,
        height: 20,
    },
});
export var BoardEditorPreview = function (props) {
    var classes = useStyles();
    var _a = useState(false), animated = _a[0], setAnimated = _a[1];
    var _b = useState(null), anchorEl = _b[0], setAnchorEl = _b[1];
    var _c = useState(false), isReplaying = _c[0], setIsReplaying = _c[1];
    var value = isReplaying ? createBoard() : props.boardValue;
    var handleOpenDrafts = function (event) {
        setAnchorEl(event.currentTarget);
    };
    var handleCloseDrafts = function () {
        setAnchorEl(null);
    };
    return (React.createElement(Box, { sx: classes.container },
        React.createElement(Box, { sx: classes.containerInner },
            React.createElement(Box, { sx: classes.boardContainer },
                React.createElement(Box, { sx: classes.animateButton },
                    React.createElement(ButtonBase, { sx: classes.modeButton, onClick: function () {
                            setAnimated(!animated);
                        } },
                        "Animation ",
                        animated ? 'ON' : 'OFF')),
                React.createElement(WysiwygEditor, { value: value, mode: "preview", animated: animated }),
                animated && (React.createElement(ButtonBase, { sx: classes.replay, onClick: function () {
                        setIsReplaying(true);
                        setTimeout(function () {
                            setIsReplaying(false);
                        }, 100);
                    } },
                    React.createElement(ReplayIcon, { sx: classes.replayButton }))))),
        React.createElement(ButtonBase, { sx: classes.close, onClick: props.onClose },
            React.createElement("img", { src: getIcon('close') })),
        React.createElement(Box, { sx: classes.bottomActionButtons },
            props.onSelectDraft && props.onSaveDraft ? (React.createElement(React.Fragment, null,
                React.createElement(Box, { sx: classes.bottomActionButton },
                    React.createElement(ButtonBase, { onClick: handleOpenDrafts }, "Drafts")),
                React.createElement(Menu, { keepMounted: true, style: {
                        zIndex: 10001,
                    }, onClose: handleCloseDrafts, anchorEl: anchorEl, open: Boolean(anchorEl) },
                    React.createElement(MenuItem, { onClick: function () {
                            if (props.onSaveDraft) {
                                props.onSaveDraft();
                            }
                            handleCloseDrafts();
                        } }, "Save"),
                    React.createElement(MenuItem, { onClick: function () {
                            if (props.onSelectDraft) {
                                props.onSelectDraft();
                            }
                            handleCloseDrafts();
                        } }, "Load")))) : (React.createElement(Box, null)),
            props.onSend ? (React.createElement(SendButton, { onSend: props.onSend, onSchedule: props.onSchedule })) : null)));
};
