var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import * as React from 'react';
import { Bit } from './Bit';
import { fontFamily } from '../../theme';
import Box from '@mui/material/Box';
import { Icon } from '../.';
import { makeVestaboardStyles } from '../../hooks/useVestaboardStyles';
var useStyles = makeVestaboardStyles({
    boardWrapper: {
        position: 'relative',
        '& > button': {
            position: 'absolute',
            backgroundColor: 'transparent',
            boxShadow: 'none',
            border: 0,
            top: 0,
            right: '4%',
            width: '8%',
            height: '14%',
            zIndex: 1,
            overflow: 'hidden',
            cursor: 'pointer',
            '& > img': {
                width: '100%',
                position: 'absolute',
                top: '-13%',
                right: 0,
            },
        },
    },
    svg: { fill: 'transparent', background: 'transparent' },
    boardBorderBlack: {
        fill: '#181818',
        stroke: '#7d878e',
        strokeWidth: 0.02,
    },
    boardBorderWhite: {
        fill: 'rgb(245,245,247)',
        stroke: 'rgb(245,245,247)',
        strokeWidth: 0.02,
    },
    childContainer: {
        fontSize: 0.1,
        fontFamily: fontFamily.default,
        fill: '#f5f5f7',
        textAlign: 'center',
    },
    childContainerLeft: {
        fontSize: 0.11,
        fontFamily: fontFamily.default,
        fill: '#7d878e',
        textAlign: 'left',
    },
    childContainerRight: {
        fontSize: 0.11,
        fontFamily: fontFamily.default,
        fill: '#7d878e',
        textAlign: 'right',
    },
    mask: {
        stroke: 'transparent',
        strokeWidth: 0.02,
        transition: 'all 500ms ease 0s',
    },
});
export var Board = function (props) {
    var classes = useStyles();
    var topOffset = props.topOffset || 0;
    var leftOffset = props.leftOffset || 0;
    return (React.createElement(Box, { sx: classes.boardWrapper },
        props.handleFavorite ? (React.createElement("button", { "aria-label": "Mark as favorite", onClick: props.handleFavorite, style: {
                position: 'absolute',
                backgroundColor: 'transparent',
                boxShadow: 'none',
                border: 0,
                top: 0,
                right: '4%',
                width: '8%',
                height: '14%',
                zIndex: 1,
                overflow: 'hidden',
                cursor: 'pointer',
            } },
            React.createElement(Icon, { type: props.isFavorite ? 'bookmark2' : 'bookmark', size: 32, style: {
                    width: '100%',
                    position: 'absolute',
                    top: '-13%',
                    right: 0,
                }, color: props.boardStyle === 'white' ? 'black' : 'white' }))) : null,
        React.createElement("svg", { viewBox: "0 0 4 2", version: "1.1", style: classes.svg, key: props.characters.length },
            React.createElement("rect", { rx: "0.1", ry: "0.1", x: leftOffset + 0.01, y: topOffset + 0.01, width: "3.98", height: "1.98", style: __assign({ stroke: props.mask || props.borderColor }, (props.boardStyle === 'white'
                    ? classes.boardBorderWhite
                    : classes.boardBorderBlack)) }),
            props.characters.map(function (row, rowIndex) {
                return row.map(function (bit, bitIndex) {
                    return (React.createElement(Bit, { boardStyle: props.boardStyle, key: "".concat(bitIndex, "-").concat(rowIndex), bit: bit, bitIndex: bitIndex, rowIndex: rowIndex, leftOffset: props.leftOffset, topOffset: props.topOffset }));
                });
            }),
            Array.isArray(props.children) ? (props.children.map(function (child, i) { return (React.createElement("text", { key: i, style: i
                    ? classes.childContainerRight
                    : classes.childContainerLeft, x: i ? 3.8 : 0.2, y: 1.78, width: "3.98", textAnchor: i ? 'end' : 'start' }, child)); })) : (React.createElement("text", { style: classes.childContainer, x: 1.8, y: 1.78, width: "3.98" }, props.children)),
            React.createElement("rect", { rx: "0.1", ry: "0.1", x: leftOffset + 0.01, y: topOffset + 0.01, width: "3.98", height: "1.98", style: __assign({ fill: props.mask || 'rgba(0, 0, 0, 0)' }, classes.mask) }))));
};
