import { Box, CircularProgress, Link } from '@mui/material';
import { MultiTimeSelect, Select, Small, TimeSelect } from '..';
import { DayOfWeek } from './types';
import React from 'react';
import { WeekDaySelector } from './WeekDaySelector';
import { makeVestaboardStyles } from '../../hooks/useVestaboardStyles';
import { useVestaboardQueryParams } from '../../hooks/useVestaboardParams';
import { useVestaboardTimezone } from '../../context/VestaboardSubscriptionContext';
export * from './types';
export var Interval;
(function (Interval) {
    Interval["Minute_1"] = "Minute_1";
    Interval["Minutes_2"] = "Minutes_2";
    Interval["Minutes_3"] = "Minutes_3";
    Interval["Minutes_4"] = "Minutes_4";
    Interval["Minutes_5"] = "Minutes_5";
    Interval["Minutes_10"] = "Minutes_10";
    Interval["Minutes_15"] = "Minutes_15";
    Interval["Minutes_20"] = "Minutes_20";
    Interval["Minutes_30"] = "Minutes_30";
    Interval["Hour"] = "Hour";
    Interval["Hour_2"] = "Hour_2";
    Interval["Hour_4"] = "Hour_4";
    Interval["Day"] = "Day";
    Interval["Week"] = "Week";
    Interval["Month"] = "Month";
    Interval["Year"] = "Year";
})(Interval || (Interval = {}));
var getInterval = function (v) {
    switch (v) {
        case 'Minute_1':
            return Interval.Minute_1;
        case 'Minutes_2':
            return Interval.Minutes_2;
        case 'Minutes_3':
            return Interval.Minutes_3;
        case 'Minutes_4':
            return Interval.Minutes_4;
        case 'Minutes_5':
            return Interval.Minutes_5;
        case 'Minutes_10':
            return Interval.Minutes_10;
        case 'Minutes_15':
            return Interval.Minutes_15;
        case 'Minutes_20':
            return Interval.Minutes_20;
        case 'Minutes_30':
            return Interval.Minutes_30;
        case 'Hour':
            return Interval.Hour;
        case 'Hour_2':
            return Interval.Hour_2;
        case 'Hour_4':
            return Interval.Hour_4;
        case 'Day':
            return Interval.Day;
        case 'Week':
            return Interval.Week;
        case 'Year':
            return Interval.Year;
        default:
            throw Error("unexpected interval string ".concat(v));
    }
};
export var parseDayOfWeek = function (index) {
    switch (index) {
        case 0:
            return DayOfWeek.Sunday;
        case 1:
            return DayOfWeek.Monday;
        case 2:
            return DayOfWeek.Tuesday;
        case 3:
            return DayOfWeek.Wednesday;
        case 4:
            return DayOfWeek.Thursday;
        case 5:
            return DayOfWeek.Friday;
        case 6:
            return DayOfWeek.Saturday;
        default:
            throw Error("invalid day of week value - ".concat(index));
    }
};
export var MonthOfYear;
(function (MonthOfYear) {
    MonthOfYear["January"] = "January";
    MonthOfYear["February"] = "February";
    MonthOfYear["March"] = "March";
    MonthOfYear["April"] = "April";
    MonthOfYear["May"] = "May";
    MonthOfYear["June"] = "June";
    MonthOfYear["July"] = "July";
    MonthOfYear["August"] = "August";
    MonthOfYear["September"] = "September";
    MonthOfYear["October"] = "October";
    MonthOfYear["November"] = "November";
    MonthOfYear["December"] = "December";
})(MonthOfYear || (MonthOfYear = {}));
export var parseDateTimeString = function (v) {
    var parts = v.split('T');
    var dateParts = parts[0].split('-');
    var timeParts = parts[1].split(':');
    var month = parseInt(dateParts[1]);
    var day = parseInt(dateParts[2]);
    var hours = parseInt(timeParts[0]);
    var minutes = parseInt(timeParts[1]);
    var amPm = hours > 12 ? 'AM' : 'PM';
    var hourAdjusted = hours > 12 ? hours - 12 : hours;
    return [
        {
            month: String(month).padStart(2, '0'),
            day: String(day).padStart(2, '0'),
        },
        {
            hour: String(hourAdjusted).padStart(2, '0'),
            minutes: String(minutes).padStart(2, '0'),
            amPm: amPm,
        },
    ];
};
export var monthOptions = [
    { id: MonthOfYear.January, name: 'January' },
    { id: MonthOfYear.February, name: 'February' },
    { id: MonthOfYear.March, name: 'March' },
    { id: MonthOfYear.April, name: 'April' },
    { id: MonthOfYear.May, name: 'May' },
    { id: MonthOfYear.June, name: 'June' },
    { id: MonthOfYear.July, name: 'July' },
    { id: MonthOfYear.August, name: 'August' },
    { id: MonthOfYear.September, name: 'September' },
    { id: MonthOfYear.October, name: 'October' },
    { id: MonthOfYear.November, name: 'November' },
    { id: MonthOfYear.December, name: 'December' },
].map(function (v) { return v.id; });
export var parseTimeString = function (v) {
    var timeParts = v.split(':');
    var hourOfDay = parseInt(timeParts[0]);
    var minutes = timeParts[1];
    var hour = (function () {
        if (hourOfDay > 12) {
            return hourOfDay - 12;
        }
        else {
            return hourOfDay;
        }
    })();
    var amPm = (function () {
        if (hourOfDay >= 12) {
            return 'PM';
        }
        else {
            return 'AM';
        }
    })();
    return {
        hour: hourOfDay === 0 ? '12' : String(hour).padStart(2, '0'),
        minutes: minutes.padStart(2, '0'),
        amPm: amPm,
    };
};
export var getDaysInMonth = function (m) {
    switch (m) {
        case MonthOfYear.April:
        case MonthOfYear.June:
        case MonthOfYear.September:
        case MonthOfYear.November:
            return 30;
        case MonthOfYear.February:
            return 29;
        default:
            return 31;
    }
};
export var getMonthNumber = function (month) {
    switch (month) {
        case MonthOfYear.January:
            return 1;
        case MonthOfYear.February:
            return 2;
        case MonthOfYear.March:
            return 3;
        case MonthOfYear.April:
            return 4;
        case MonthOfYear.May:
            return 5;
        case MonthOfYear.June:
            return 6;
        case MonthOfYear.July:
            return 7;
        case MonthOfYear.August:
            return 8;
        case MonthOfYear.September:
            return 9;
        case MonthOfYear.October:
            return 10;
        case MonthOfYear.November:
            return 11;
        case MonthOfYear.December:
            return 12;
        default:
            throw Error("unexpected month - ".concat(month));
    }
};
var getMonth = function (month) {
    switch (month) {
        case 'January':
            return MonthOfYear.January;
        case 'February':
            return MonthOfYear.February;
        case 'March':
            return MonthOfYear.March;
        case 'April':
            return MonthOfYear.April;
        case 'May':
            return MonthOfYear.May;
        case 'June':
            return MonthOfYear.June;
        case 'July':
            return MonthOfYear.July;
        case 'August':
            return MonthOfYear.August;
        case 'September':
            return MonthOfYear.September;
        case 'October':
            return MonthOfYear.October;
        case 'November':
            return MonthOfYear.November;
        case 'December':
            return MonthOfYear.December;
        default:
            throw Error("unexpected month - ".concat(month));
    }
};
var getDayOfWeek = function (v) {
    switch (v) {
        case 'Sunday':
            return DayOfWeek.Sunday;
        case 'Monday':
            return DayOfWeek.Monday;
        case 'Tuesday':
            return DayOfWeek.Tuesday;
        case 'Wednesday':
            return DayOfWeek.Wednesday;
        case 'Thursday':
            return DayOfWeek.Thursday;
        case 'Friday':
            return DayOfWeek.Friday;
        case 'Saturday':
            return DayOfWeek.Saturday;
        default:
            throw Error("invalid day of week value - ".concat(v));
    }
};
export var WeekdayVsWeekendSelection;
(function (WeekdayVsWeekendSelection) {
    WeekdayVsWeekendSelection["WeekdaysOnly"] = "weekdays";
    WeekdayVsWeekendSelection["WeekendsOnly"] = "weekends";
    WeekdayVsWeekendSelection["Either"] = "either";
})(WeekdayVsWeekendSelection || (WeekdayVsWeekendSelection = {}));
var useStyles = makeVestaboardStyles({
    rangeContainer: {
        display: 'flex',
        justifyContent: 'space-between',
        '@media(max-width: 660px)': {
            flexDirection: 'column',
        },
    },
});
export var CadencePicker = function (props) {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k;
    var classes = useStyles();
    var _l = React.useState((_c = (_b = (_a = props.cadence) === null || _a === void 0 ? void 0 : _a.interval) !== null && _b !== void 0 ? _b : props.defaultInterval) !== null && _c !== void 0 ? _c : null), interval = _l[0], setInterval = _l[1];
    var _m = React.useState((_d = props.defaultEndTime) !== null && _d !== void 0 ? _d : {
        hour: '06',
        minutes: '00',
        amPm: 'PM',
    }), endAtTime = _m[0], setEndAtTime = _m[1];
    var defaultStart = (_e = props.defaultStartTime) !== null && _e !== void 0 ? _e : {
        hour: '10',
        minutes: '00',
        amPm: 'AM',
    };
    var _o = React.useState(defaultStart), startAtTime = _o[0], setStartAtTime = _o[1];
    var _p = React.useState([
        {
            time: defaultStart,
            label: 'Time',
            index: 0,
        },
    ]), specificTimes = _p[0], setSpecificTimes = _p[1];
    var _q = React.useState(null), dayOfWeek = _q[0], setDayOfWeek = _q[1];
    var _r = React.useState(props.defaultShowOn ? (_f = props.defaultShowOn) === null || _f === void 0 ? void 0 : _f.month : null), monthOfYear = _r[0], setMonthOfYear = _r[1];
    var _s = React.useState(props.defaultShowOn ? (_g = props.defaultShowOn) === null || _g === void 0 ? void 0 : _g.day : null), dayOfMonth = _s[0], setDayOfMonth = _s[1];
    var _t = React.useState(null), timezone = _t[0], setTimezone = _t[1];
    var _u = React.useState(props.cadence && 'daysOfTheWeek' in props.cadence
        ? (_j = (_h = props.cadence) === null || _h === void 0 ? void 0 : _h.daysOfTheWeek) !== null && _j !== void 0 ? _j : []
        : (_k = props.defaultDays) !== null && _k !== void 0 ? _k : []), daysOfTheWeekSelection = _u[0], setDaysOfTheWeekSelection = _u[1];
    React.useEffect(function () {
        if (props.cadence) {
            switch (props.cadence.interval) {
                case Interval.Minute_1:
                case Interval.Minutes_2:
                case Interval.Minutes_3:
                case Interval.Minutes_4:
                case Interval.Minutes_5:
                case Interval.Minutes_10:
                case Interval.Minutes_15:
                case Interval.Minutes_20:
                case Interval.Minutes_30:
                case Interval.Hour:
                case Interval.Hour_2:
                case Interval.Hour_4:
                    setStartAtTime(props.cadence.startAtTime);
                    setEndAtTime(props.cadence.endAtTime);
                    break;
                case Interval.Day:
                    setSpecificTimes(props.cadence.startAtTimes.map(function (t, index) { return ({
                        label: 'Time',
                        index: index,
                        time: t,
                    }); }));
                    break;
                case Interval.Week:
                    setStartAtTime(props.cadence.timeToDisplay);
                    setDayOfWeek(props.cadence.dayOfWeek);
                    break;
                case Interval.Year:
                    setStartAtTime(props.cadence.time);
                    setDayOfMonth(props.cadence.day);
                    setMonthOfYear(props.cadence.month);
                    break;
                default:
                    return undefined;
            }
        }
    }, []);
    React.useEffect(function () {
        var cadenceValue = (function () {
            switch (interval) {
                case Interval.Minute_1:
                case Interval.Minutes_2:
                case Interval.Minutes_3:
                case Interval.Minutes_4:
                case Interval.Minutes_5:
                case Interval.Minutes_10:
                case Interval.Minutes_15:
                case Interval.Minutes_20:
                case Interval.Minutes_30:
                case Interval.Hour:
                case Interval.Hour_2:
                case Interval.Hour_4:
                    if (startAtTime) {
                        return {
                            interval: interval,
                            startAtTime: startAtTime,
                            endAtTime: endAtTime || startAtTime,
                            daysOfTheWeek: daysOfTheWeekSelection,
                        };
                    }
                case Interval.Day:
                    if (specificTimes) {
                        return {
                            interval: interval,
                            startAtTimes: specificTimes.map(function (t) { return t.time; }),
                            daysOfTheWeek: daysOfTheWeekSelection,
                        };
                    }
                case Interval.Week:
                    if (dayOfWeek && startAtTime) {
                        return {
                            interval: interval,
                            dayOfWeek: dayOfWeek,
                            timeToDisplay: startAtTime,
                        };
                    }
                case Interval.Year:
                    if (monthOfYear && dayOfMonth && startAtTime) {
                        return {
                            interval: interval,
                            month: monthOfYear,
                            day: dayOfMonth,
                            time: startAtTime,
                        };
                    }
                default:
                    return undefined;
            }
        })();
        if (cadenceValue) {
            props.onChange(cadenceValue, timezone);
        }
    }, [
        specificTimes,
        dayOfWeek,
        monthOfYear,
        dayOfMonth,
        interval,
        startAtTime,
        endAtTime,
        daysOfTheWeekSelection,
    ]);
    var updateInterval = function (v) {
        setSpecificTimes([]);
        setDayOfWeek(null);
        setInterval(v);
    };
    var intervalFields = React.useMemo(function () {
        var _a, _b, _c, _d, _e;
        switch (interval) {
            case Interval.Minute_1:
            case Interval.Minutes_2:
            case Interval.Minutes_3:
            case Interval.Minutes_4:
            case Interval.Minutes_5:
            case Interval.Minutes_10:
            case Interval.Minutes_15:
            case Interval.Minutes_20:
            case Interval.Minutes_30:
            case Interval.Hour:
            case Interval.Hour_2:
            case Interval.Hour_4:
                return (React.createElement(React.Fragment, null,
                    React.createElement(Box, { sx: classes.rangeContainer },
                        !props.disableStartTime ? (React.createElement(TimeSelect, { isTwentyFourHourTime: props.isTwentyFourHourTime, key: "start-at", disableLabel: true, label: "Start at", value: (_a = startAtTime !== null && startAtTime !== void 0 ? startAtTime : props.defaultStartTime) !== null && _a !== void 0 ? _a : {
                                hour: '10',
                                minutes: '00',
                                amPm: 'AM',
                            }, setValue: setStartAtTime })) : null,
                        !props.disableEndTime ? (React.createElement(TimeSelect, { isTwentyFourHourTime: props.isTwentyFourHourTime, key: "end-at", disableLabel: true, label: "End at", value: endAtTime !== null && endAtTime !== void 0 ? endAtTime : {
                                hour: '11',
                                minutes: '00',
                                amPm: 'AM',
                            }, setValue: setEndAtTime })) : null),
                    props.allowWeekdaySelection ? (React.createElement(WeekDaySelector, { value: daysOfTheWeekSelection, onValueChange: setDaysOfTheWeekSelection })) : null));
            case Interval.Day:
                if (props.allowMultipleTimes != false) {
                    return (React.createElement(React.Fragment, null,
                        React.createElement(MultiTimeSelect, { maxTimes: 10, value: specificTimes, onChange: function (times) { return setSpecificTimes(times); }, isTwentyFourHourTime: props.isTwentyFourHourTime }),
                        props.allowWeekdaySelection ? (React.createElement(WeekDaySelector, { value: daysOfTheWeekSelection, onValueChange: setDaysOfTheWeekSelection })) : null));
                }
                else {
                    return (React.createElement(React.Fragment, null,
                        React.createElement(TimeSelect, { isTwentyFourHourTime: props.isTwentyFourHourTime, disableLabel: true, label: "Send at", setLabel: function () { }, value: (_d = (_c = (_b = specificTimes[0]) === null || _b === void 0 ? void 0 : _b.time) !== null && _c !== void 0 ? _c : props.defaultStartTime) !== null && _d !== void 0 ? _d : {
                                hour: '10',
                                minutes: '00',
                                amPm: 'AM',
                            }, setValue: function (v) {
                                setSpecificTimes([{ time: v, label: 'Time', index: 0 }]);
                            } }),
                        props.allowWeekdaySelection ? (React.createElement(WeekDaySelector, { value: daysOfTheWeekSelection, onValueChange: setDaysOfTheWeekSelection })) : null));
                }
            case Interval.Week:
                return (React.createElement(Box, { display: 'flex', flexDirection: 'row', style: { justifyContent: 'space-between' } },
                    React.createElement(Box, { display: 'flex', flexDirection: 'column', style: { paddingTop: 2 } },
                        React.createElement(Select, { value: dayOfWeek !== null && dayOfWeek !== void 0 ? dayOfWeek : '', label: "Show on", onValueChange: function (v) { return setDayOfWeek(getDayOfWeek(v)); }, options: [
                                { id: DayOfWeek.Sunday, name: 'Sunday' },
                                { id: DayOfWeek.Monday, name: 'Monday' },
                                { id: DayOfWeek.Tuesday, name: 'Tuesday' },
                                { id: DayOfWeek.Wednesday, name: 'Wednesday' },
                                { id: DayOfWeek.Thursday, name: 'Thursday' },
                                { id: DayOfWeek.Friday, name: 'Friday' },
                                { id: DayOfWeek.Saturday, name: 'Saturday' },
                            ] })),
                    React.createElement(Box, { display: 'flex', flexDirection: 'column' },
                        React.createElement(TimeSelect, { isTwentyFourHourTime: props.isTwentyFourHourTime, disableLabel: true, label: "Show at", setLabel: function () { }, value: startAtTime !== null && startAtTime !== void 0 ? startAtTime : {
                                hour: '10',
                                minutes: '00',
                                amPm: 'AM',
                            }, setValue: setStartAtTime }))));
            case Interval.Year:
                return (React.createElement(React.Fragment, null,
                    !props.hideShowOn && (React.createElement(Box, { sx: {
                            display: 'flex',
                            alignItems: 'end',
                            justifyContent: 'space-between',
                            my: 1,
                        } },
                        React.createElement(Box, { sx: { mt: 1, flex: 1, marginRight: 6 } },
                            React.createElement(Select, { value: monthOfYear !== null && monthOfYear !== void 0 ? monthOfYear : '', disabled: props.disableShowOn, label: "Show on", onValueChange: function (v) {
                                    if (props.disableShowOn)
                                        return;
                                    setDayOfMonth(null);
                                    setMonthOfYear(getMonth(v));
                                }, options: [
                                    { id: MonthOfYear.January, name: 'January' },
                                    { id: MonthOfYear.February, name: 'February' },
                                    { id: MonthOfYear.March, name: 'March' },
                                    { id: MonthOfYear.April, name: 'April' },
                                    { id: MonthOfYear.May, name: 'May' },
                                    { id: MonthOfYear.June, name: 'June' },
                                    { id: MonthOfYear.July, name: 'July' },
                                    { id: MonthOfYear.August, name: 'August' },
                                    { id: MonthOfYear.September, name: 'September' },
                                    { id: MonthOfYear.October, name: 'October' },
                                    { id: MonthOfYear.November, name: 'November' },
                                    { id: MonthOfYear.December, name: 'December' },
                                ] })),
                        React.createElement(Box, { sx: { flex: 1, marginLeft: 6 } },
                            React.createElement(Select, { value: (_e = String(dayOfMonth)) !== null && _e !== void 0 ? _e : '', disabled: props.disableShowOn, onValueChange: function (v) {
                                    if (props.disableShowOn)
                                        return;
                                    setDayOfMonth(parseInt(v));
                                }, options: monthOfYear
                                    ? Array(getDaysInMonth(monthOfYear))
                                        .fill(null)
                                        .map(function (x, index) { return ({
                                        id: String(index + 1),
                                        name: String(index + 1),
                                    }); })
                                    : [] })))),
                    React.createElement(Box, { display: 'flex' },
                        React.createElement(TimeSelect, { isTwentyFourHourTime: props.isTwentyFourHourTime, disableLabel: true, label: "Show at", setLabel: function () { }, value: startAtTime !== null && startAtTime !== void 0 ? startAtTime : {
                                hour: '10',
                                minutes: '00',
                                amPm: 'AM',
                            }, setValue: setStartAtTime }))));
        }
    }, [
        interval,
        startAtTime,
        specificTimes,
        dayOfMonth,
        monthOfYear,
        dayOfWeek,
        endAtTime,
        daysOfTheWeekSelection,
    ]);
    return (React.createElement(Box, null,
        !props.hideFrequencySelector && (React.createElement(Select, { options: [
                { id: Interval.Minute_1, name: 'Minute' },
                { id: Interval.Minutes_2, name: '2 Minutes' },
                { id: Interval.Minutes_3, name: '3 Minutes' },
                { id: Interval.Minutes_4, name: '4 Minutes' },
                { id: Interval.Minutes_5, name: '5 Minutes' },
                { id: Interval.Minutes_10, name: '10 Minutes' },
                { id: Interval.Minutes_15, name: '15 Minutes' },
                { id: Interval.Minutes_20, name: '20 Minutes' },
                { id: Interval.Minutes_30, name: '30 Minutes' },
                { id: Interval.Hour, name: 'Hour' },
                { id: Interval.Hour_2, name: '2 Hours' },
                { id: Interval.Hour_4, name: '4 Hours' },
                { id: Interval.Day, name: 'Day' },
                { id: Interval.Week, name: 'Week' },
                { id: Interval.Year, name: (props === null || props === void 0 ? void 0 : props.yearlyString) || 'Year' },
            ].filter(function (inv) {
                return props.intervals ? props.intervals.indexOf(inv.id) > -1 : true;
            }), value: interval !== null && interval !== void 0 ? interval : '', onValueChange: function (v) { return (v ? updateInterval(getInterval(v)) : null); }, label: "Repeat Every" })),
        React.createElement(Box, { sx: { my: 1 } }, intervalFields)));
};
export var TimezoneSetter = function (props) {
    var _a = useVestaboardQueryParams(), subscriptionId = _a.subscriptionId, platform = _a.platform;
    var _b = useVestaboardTimezone(), subscriptionConfigTimezone = _b.value, loading = _b.loading;
    var returnToUrl = btoa("https://platform.vestaboard.com/deeplink/subscription/".concat(subscriptionId, "/config"));
    React.useEffect(function () {
        if (subscriptionConfigTimezone && props.onReceivedTimezone) {
            props.onReceivedTimezone(subscriptionConfigTimezone);
        }
    }, [subscriptionConfigTimezone]);
    if (loading)
        return React.createElement(CircularProgress, null);
    var verb = (function () {
        switch (!!subscriptionConfigTimezone) {
            case true:
                return 'Adjust';
            case false:
                return 'Set';
        }
    })();
    return (React.createElement(React.Fragment, null, subscriptionConfigTimezone ? (React.createElement(React.Fragment, null,
        React.createElement(Small, null,
            "Your timezone is set to ",
            subscriptionConfigTimezone,
            ".",
            ' ',
            platform == 'ios' || platform == 'android' ? (React.createElement(React.Fragment, null,
                verb,
                " your timezone in",
                ' ',
                React.createElement(Link, { color: "inherit", underline: "always", href: "https://platform.vestaboard.com/deeplink/settings/timezone?returnTo=".concat(returnToUrl) }, "Settings"))) : (React.createElement(React.Fragment, null,
                verb,
                " your timezone in Settings."))))) : (React.createElement(Small, null,
        "Set your timezone in",
        ' ',
        platform == 'ios' || platform == 'android' ? (React.createElement(Link, { color: "inherit", underline: "always", href: "https://platform.vestaboard.com/deeplink/settings/timezone?returnTo=".concat(returnToUrl) }, "Settings")) : ('Settings')))));
};
