import Box from '@mui/material/Box';
import ButtonBase from '@mui/material/ButtonBase';
import React, { useEffect, useRef } from 'react';
import Typography from '@mui/material/Typography';
import { fontFamily } from '../theme';
import { getIcon } from '../utils/getIcon';
import { Spacer } from '..';
import { makeVestaboardStyles } from '../hooks/useVestaboardStyles';
var useStyles = makeVestaboardStyles({
    container: {
        position: 'fixed',
        top: 0,
        left: 0,
        width: '100vw',
        height: '100vh',
        backgroundColor: 'rgba(10, 10, 11, 0.9)',
        zIndex: 10000,
        overflow: 'hidden',
        backdropFilter: 'blur(6px)',
    },
    close: {
        position: 'absolute',
        top: 28,
        right: 22,
    },
    closeSmall: {
        position: 'absolute',
        top: 14,
        right: 22,
    },
    header: {
        height: 138,
        width: '100%',
        display: 'flex',
        alignItems: 'center',
        justifyContent: 'center',
        borderBottom: 'solid 1px #2b2b2b',
    },
    headerSmall: {
        height: 50,
        width: '100%',
        display: 'flex',
        alignItems: 'center',
        justifyContent: 'center',
        borderBottom: 'solid 1px #2b2b2b',
    },
    title: {
        color: '#f5f5f7',
        fontFamily: fontFamily.default,
        fontSize: 44,
        fontWeight: 500,
        lineHeight: 1.18,
    },
    content: {
        maxWidth: '926px',
        width: "calc(100% - 44px)",
    },
    contentMain: {
        height: 'calc(100vh - 138px)',
        overflow: 'auto',
        display: 'flex',
        justifyContent: 'center',
    },
    contentMainSmall: {
        height: 'calc(100vh - 50px)',
        overflow: 'auto',
        display: 'flex',
        justifyContent: 'center',
    },
});
export var FullModal = function (props) {
    var classes = useStyles();
    var modalRef = useRef(null);
    var onClose = props.onClose;
    useEffect(function () {
        var handleEscape = function (e) {
            if (e.key === 'Escape') {
                onClose();
            }
        };
        window.addEventListener('keydown', handleEscape);
        return function () {
            window.removeEventListener('keydown', handleEscape);
        };
    }, []);
    return (React.createElement("div", { style: classes.container, ref: modalRef },
        props.title ? (React.createElement(React.Fragment, null,
            React.createElement(Box, { sx: classes.header },
                React.createElement(Box, { sx: classes.content },
                    React.createElement(Typography, { sx: classes.title }, props.title))),
            React.createElement(ButtonBase, { sx: classes.close, onClick: props.onClose },
                React.createElement("img", { src: getIcon('close') })))) : (React.createElement(Box, { sx: classes.headerSmall },
            React.createElement(ButtonBase, { sx: classes.closeSmall, onClick: props.onClose },
                React.createElement("img", { src: getIcon('close') })))),
        React.createElement(Box, { sx: props.title ? classes.contentMain : classes.contentMainSmall },
            React.createElement(Box, { sx: classes.content },
                React.createElement(Spacer, { size: "large" }),
                props.children,
                React.createElement(Spacer, { size: "large" })))));
};
