import React, { useCallback, useEffect, useRef } from 'react';
import { ButtonBase } from '@mui/material';
import { Player as LottieView } from '@lottiefiles/react-lottie-player';
import favoriteAnimation from './favoriteAnimation.json';
import favoriteAnimationWhite from './favoriteAnimationWhite.json';
export var FavoriteButton = function (_a) {
    var isFavorite = _a.isFavorite, onPress = _a.onPress, boardStyle = _a.boardStyle, loading = _a.loading;
    var animation = useRef(null);
    var favoriteTimerRef = useRef(null);
    var runFavoriteAnimation = useCallback(function () {
        var _a, _b, _c;
        (_a = animation.current) === null || _a === void 0 ? void 0 : _a.setSeeker(0, true);
        (_b = animation.current) === null || _b === void 0 ? void 0 : _b.setPlayerDirection(1);
        (_c = animation.current) === null || _c === void 0 ? void 0 : _c.play();
    }, []);
    var runUnFavoriteAnimation = useCallback(function () {
        var _a, _b, _c;
        (_a = animation.current) === null || _a === void 0 ? void 0 : _a.setSeeker(20, true);
        (_b = animation.current) === null || _b === void 0 ? void 0 : _b.setPlayerDirection(-1);
        (_c = animation.current) === null || _c === void 0 ? void 0 : _c.play();
    }, []);
    var toggleAnimation = useCallback(function (isFavorited) {
        if (isFavorited) {
            runUnFavoriteAnimation();
        }
        else {
            runFavoriteAnimation();
        }
    }, [runUnFavoriteAnimation, runFavoriteAnimation]);
    var handleFavorite = useCallback(function () {
        if (favoriteTimerRef.current) {
            clearTimeout(favoriteTimerRef.current);
            toggleAnimation(!isFavorite);
            favoriteTimerRef.current = null;
            return;
        }
        if (onPress) {
            toggleAnimation(isFavorite);
            var favoriteTimer = setTimeout(function () {
                onPress(isFavorite);
                favoriteTimerRef.current = null;
            }, 1500);
            favoriteTimerRef.current = favoriteTimer;
        }
    }, [isFavorite, onPress, toggleAnimation]);
    useEffect(function () {
        var timeout = setTimeout(function () {
            var _a, _b;
            if (isFavorite) {
                (_a = animation.current) === null || _a === void 0 ? void 0 : _a.setSeeker(20, true);
            }
            else {
                (_b = animation.current) === null || _b === void 0 ? void 0 : _b.setSeeker(0, true);
            }
        }, 25);
        return function () {
            clearTimeout(timeout);
            if (favoriteTimerRef.current) {
                clearTimeout(favoriteTimerRef.current);
                favoriteTimerRef.current = null;
                onPress(isFavorite);
            }
        };
    }, [isFavorite, onPress]);
    return (React.createElement("div", { style: {
            position: 'absolute',
            width: 16,
            top: -18,
            right: 0,
            height: 21,
            padding: 12,
        } },
        React.createElement(ButtonBase, { style: { flex: 1 }, onClick: !loading ? handleFavorite : undefined },
            React.createElement(LottieView, { ref: animation, keepLastFrame: true, loop: false, style: {
                    width: 20,
                    height: 30,
                }, src: boardStyle === 'white' ? favoriteAnimationWhite : favoriteAnimation }))));
};
