var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import * as React from 'react';
import Box from '@mui/material/Box';
import ButtonBase from '@mui/material/ButtonBase';
import { getIcon } from '../utils/getIcon';
import useMediaQuery from '@mui/material/useMediaQuery';
import { responsive } from '../theme';
import { makeVestaboardStyles } from '../hooks/useVestaboardStyles';
var useStyles = makeVestaboardStyles(function (props) {
    var _a, _b, _c;
    return ({
        background: {
            backgroundColor: "rgba(10, 10, 11, 0.8)",
            position: 'fixed',
            width: '100vw',
            height: '100vh',
            left: 0,
            top: 0,
            opacity: 0,
            transition: 'opacity 1s',
            pointerEvents: 'none',
            zIndex: 9990,
        },
        backgroundActive: {
            visibility: 'visible',
            opacity: 1,
            pointerEvents: 'all',
            transition: 'opacity 1s',
            backdropFilter: props.blur ? 'blur(10px)' : 'blur(0px)',
        },
        modal: {
            position: 'fixed',
            width: '100vw',
            height: '100vh',
            transition: 'opacity 1s',
            pointerEvents: 'none',
            zIndex: 9999,
            top: 0,
            left: 0,
            justifyContent: 'center',
            alignItems: 'center',
            display: 'flex',
            opacity: 0,
        },
        modalActive: {
            pointerEvents: 'all',
            opacity: 1,
            transition: 'opacity 1s',
        },
        modalContent: (_a = {
                position: 'fixed',
                padding: "36px 56px",
                maxWidth: props.fullScreenDesktop ? '100vw' : responsive.MOBILE,
                width: '100%',
                backdropFilter: props.transparent ? 'blur(0px)' : 'blur(10px)',
                backgroundColor: props.transparent
                    ? 'transparent'
                    : 'rgba(125, 135, 142, 0.2)',
                borderRadius: '6px',
                maxHeight: '70vh',
                overflow: 'auto'
            },
            _a["@media(max-width: ".concat(responsive.MOBILE, "px)")] = {
                marginTop: '74px',
                width: props.fullScreenMobile || props.fullScreenDesktop ? '100%' : '60%',
                maxWidth: '100vw',
                maxHeight: props.fullScreenMobile || props.fullScreenDesktop ? '100vh' : '70vh',
                height: '100%',
            },
            _a),
        close: (_b = {
                position: 'absolute',
                right: 36,
                top: 36
            },
            _b["@media(max-width: ".concat(responsive.MOBILE, "px)")] = {
                position: 'absolute',
                top: 10,
                right: 10,
            },
            _b),
        back: (_c = {
                position: 'absolute',
                left: 36,
                top: 36
            },
            _c["@media(max-width: ".concat(responsive.MOBILE, "px)")] = {
                position: 'absolute',
                top: 10,
                left: 10,
            },
            _c),
    });
});
export var Modal = function (props) {
    var classes = useStyles(props);
    var isMobile = useMediaQuery('(max-width: ' + responsive.MOBILE + 'px)');
    var onClose = props.onClose, goBack = props.goBack;
    React.useEffect(function () {
        var handleEscape = function (e) {
            if (e.key === 'Escape') {
                onClose && onClose();
            }
        };
        window.addEventListener('keydown', handleEscape);
        return function () {
            window.removeEventListener('keydown', handleEscape);
        };
    }, []);
    if (isMobile) {
        return (React.createElement("div", null,
            React.createElement(ButtonBase, { sx: __assign(__assign({}, classes.background), (props.visible ? classes.backgroundActive : {})), onClick: props.onClose }),
            React.createElement(Box, { sx: __assign(__assign({}, classes.modal), (props.visible ? classes.modalActive : {})) },
                React.createElement(Box, { sx: classes.modalContent }, props.children),
                !!goBack && (React.createElement(ButtonBase, { sx: classes.back, onClick: props.goBack },
                    React.createElement("img", { src: getIcon('icon-back'), alt: "Close" }))),
                !!onClose && (React.createElement(ButtonBase, { sx: classes.close, onClick: props.onClose },
                    React.createElement("img", { src: getIcon('close'), alt: "Close" }))))));
    }
    return (React.createElement(React.Fragment, null,
        React.createElement(ButtonBase, { sx: __assign(__assign({}, classes.background), (props.visible ? classes.backgroundActive : {})), onClick: props.onClose }),
        React.createElement(Box, { sx: __assign(__assign({}, classes.modal), (props.visible ? classes.modalActive : {})) },
            !!goBack && (React.createElement(ButtonBase, { sx: classes.back, onClick: props.goBack },
                React.createElement("img", { src: getIcon('icon-back'), alt: "Close" }))),
            React.createElement(Box, { sx: classes.modalContent },
                !!onClose && (React.createElement(ButtonBase, { sx: classes.close, onClick: props.onClose },
                    React.createElement("img", { src: getIcon('close'), alt: "Close" }))),
                props.children))));
};
