var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import * as React from 'react';
import Box from '@mui/material/Box';
import ButtonBase from '@mui/material/ButtonBase';
import useMediaQuery from '@mui/material/useMediaQuery';
import { responsive } from '../theme';
import { useState } from 'react';
import { makeVestaboardStyles } from '../hooks/useVestaboardStyles';
var useStyles = makeVestaboardStyles(function (props) {
    var _a, _b;
    return ({
        header: {
            backgroundColor: 'rgb(43,45,46)',
            display: 'flex',
            padding: "36px 56px",
            alignItems: 'center',
            flexDirection: 'column',
        },
        footer: {
            backgroundColor: 'rgb(43,45,46)',
            display: 'flex',
            padding: "36px 56px",
            gap: '16px',
            justifyContent: 'space-between',
        },
        mobileFooter: {
            backgroundColor: 'rgb(43,45,46)',
            display: 'flex',
            padding: "18px 14px",
            gap: '16px',
            justifyContent: 'space-between',
            marginTop: '24px',
        },
        body: {
            backgroundColor: "rgba(33,35,35)",
            display: 'flex',
            padding: "36px 56px",
        },
        background: {
            backgroundColor: "rgba(10, 10, 11, 0.9)",
            position: 'fixed',
            width: '100vw',
            height: '100vh',
            left: 0,
            top: 0,
            opacity: 0,
            transition: 'opacity 1s',
            pointerEvents: 'none',
            zIndex: 9990,
        },
        backgroundActive: {
            visibility: 'visible',
            opacity: 1,
            pointerEvents: 'all',
            transition: 'opacity 1s',
        },
        modal: {
            position: 'fixed',
            width: '100vw',
            height: '100vh',
            transition: 'opacity 1s',
            pointerEvents: 'none',
            zIndex: 9999,
            top: 0,
            left: 0,
            justifyContent: 'center',
            alignItems: 'center',
            display: 'flex',
            opacity: 0,
            flexDirection: 'column',
        },
        modalActive: {
            pointerEvents: 'all',
            opacity: 1,
            transition: 'opacity 1s',
        },
        modalContent: (_a = {
                position: 'fixed',
                width: 792,
                maxWidth: '100vw',
                backgroundColor: props.transparent ? 'transparent' : "rgba(33,35,35)",
                borderRadius: '6px',
                maxHeight: '96vh',
                overflow: 'hidden'
            },
            _a["@media(max-width: ".concat(responsive.MOBILE, "px)")] = {
                overflow: 'auto',
                width: props.fullScreenMobile ? '100%' : '60%',
                maxHeight: props.fullScreenMobile ? '100vh' : '96vh',
                height: '100%',
            },
            _a),
        close: (_b = {
                position: 'absolute',
                right: 36,
                top: 36
            },
            _b["@media(max-width: ".concat(responsive.MOBILE, "px)")] = {
                position: 'absolute',
                right: props.fullScreenMobile ? 40 : 36,
                top: props.fullScreenMobile ? 40 : 36,
            },
            _b),
    });
});
export var ModalDialog = function (props) {
    var classes = useStyles(props);
    var _a = useState(0), touchStart = _a[0], setTouchStart = _a[1];
    var _b = useState(0), touchEnd = _b[0], setTouchEnd = _b[1];
    var isMobile = useMediaQuery('(max-width: ' + responsive.MOBILE + 'px)');
    var onClose = props.onClose;
    React.useEffect(function () {
        var handleEscape = function (e) {
            if (e.key === 'Escape') {
                onClose();
            }
        };
        window.addEventListener('keydown', handleEscape);
        return function () {
            window.removeEventListener('keydown', handleEscape);
        };
    }, []);
    var handleTouchStart = function (e) {
        setTouchStart(e.targetTouches[0].clientY);
    };
    var handleTouchMove = function (e) {
        setTouchEnd(e.targetTouches[0].clientY);
    };
    var handleTouchEnd = function () {
        if (touchStart - touchEnd > 100) {
            props.onClose();
        }
        if (touchStart - touchEnd < -100) {
            props.onClose();
        }
    };
    if (isMobile) {
        return (React.createElement("div", { onTouchStart: handleTouchStart, onTouchMove: handleTouchMove, onTouchEnd: handleTouchEnd },
            React.createElement(ButtonBase, { sx: __assign(__assign({}, classes.background), (props.visible ? classes.backgroundActive : {})), onClick: props.onClose }),
            React.createElement(Box, { sx: __assign(__assign({}, classes.modal), (props.visible ? classes.modalActive : {})) },
                React.createElement(Box, { sx: classes.modalContent },
                    React.createElement(Box, { sx: classes.header }, props.header),
                    React.createElement(Box, { sx: classes.body }, props.children),
                    React.createElement(Box, { sx: isMobile ? classes.mobileFooter : classes.footer }, props.footer)))));
    }
    return (React.createElement(React.Fragment, null,
        React.createElement(ButtonBase, { sx: __assign(__assign({}, classes.background), (props.visible ? classes.backgroundActive : {})), onClick: props.onClose }),
        React.createElement(Box, { sx: __assign(__assign({}, classes.modal), (props.visible ? classes.modalActive : {})) },
            React.createElement(Box, { sx: classes.modalContent },
                React.createElement(Box, { sx: classes.header }, props.header),
                React.createElement(Box, { style: {
                        maxHeight: '65vh',
                        height: '100%',
                        overflow: 'auto',
                        backgroundColor: "rgba(33,35,35)",
                    } },
                    React.createElement(Box, { sx: classes.body }, props.children)),
                React.createElement(Box, { sx: classes.footer }, props.footer)))));
};
