var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { Box } from '@mui/material';
import React, { useEffect, useRef } from 'react';
import { characterCodes } from '../../characterCodes';
import { getBitValue } from '../../utils/getBitValue';
import { getInternationalKey } from '../../utils/getInternationalKey';
import BitWhite from '../../assets/bit-white.png';
import BitBlack from '../../assets/bit-black.png';
import { makeVestaboardStyles } from '../../hooks/useVestaboardStyles';
var useStyles = makeVestaboardStyles({
    container: {
        flex: 1,
        marginRight: '1%',
        backgroundSize: 'cover',
        position: 'relative',
    },
    containerBlack: {
        backgroundImage: "url(".concat(BitBlack, ")"),
    },
    containerWhite: {
        backgroundImage: "url(".concat(BitWhite, ")"),
    },
    input: {
        width: '100%',
        height: '100%',
        background: 'transparent',
        border: 0,
        fontFamily: '"VestaboardWYSIWYG","Roboto",sans-serif',
        textAlign: 'center',
        outline: 'none',
        overflow: 'auto',
        position: 'absolute',
        top: 0,
        left: 0,
        zIndex: 1,
        padding: 0,
    },
    inputLight: {
        color: '#000',
    },
    inputDark: {
        color: '#FFF',
    },
});
export var Bit = function (props) {
    var bitRef = useRef(null);
    var classes = useStyles();
    var _changeEvent = null;
    // Make the font size dynamic
    useEffect(function () {
        var renderFontSize = function () {
            if (bitRef.current) {
                var width = bitRef.current.getBoundingClientRect().width;
                var fontSize = "".concat(parseInt("".concat(width * 0.8), 10), "px");
                bitRef.current.style.fontSize = fontSize;
                bitRef.current.style.lineHeight = fontSize;
            }
        };
        window.addEventListener('resize', renderFontSize);
        renderFontSize();
        return function () {
            window.removeEventListener('resize', renderFontSize);
        };
    }, []);
    useEffect(function () {
        if (!props.animated) {
            return;
        }
        var codeIndex = characterCodes.reduce(function (prev, current, index) {
            if (current.code === props.code) {
                return index;
            }
            return prev;
        }, null);
        if (!codeIndex) {
            return;
        }
        var animatedBit = 0;
        var displayBackgroundColor = !backgroundColor || backgroundColor === '#171818'
            ? '#2c2c2c'
            : backgroundColor;
        var animationInterval = setInterval(function () {
            if ((animatedBit || 0) !== codeIndex) {
                animatedBit++;
                if (bitRef.current) {
                    bitRef.current.value = characterCodes[animatedBit].value;
                    if (bitRef.current.parentElement) {
                        var backgroundColor_1 = characterCodes[animatedBit].previewColor ||
                            characterCodes[animatedBit].color;
                        bitRef.current.parentElement.style.backgroundColor = displayBackgroundColor;
                    }
                }
            }
            else {
                clearInterval(animationInterval);
                if (bitRef.current) {
                    bitRef.current.value = getBitValue(props.code) || '';
                }
            }
        }, 50);
        return function () { return clearTimeout(animationInterval); };
    }, [props.animated, props.code]);
    var value = getBitValue(props.code) || '';
    var characterCode = characterCodes.find(function (characterCode) { return characterCode.code === props.code; });
    var backgroundColor = props.code === 71 && props.boardStyle === 'white'
        ? //  support for 71
            (characterCode === null || characterCode === void 0 ? void 0 : characterCode.inverseColor) || (characterCode === null || characterCode === void 0 ? void 0 : characterCode.inversePreviewColor)
        : (characterCode === null || characterCode === void 0 ? void 0 : characterCode.previewColor) || (characterCode === null || characterCode === void 0 ? void 0 : characterCode.color);
    return (React.createElement(Box, { sx: __assign(__assign({}, classes.container), (props.boardStyle === 'white'
            ? classes.containerWhite
            : classes.containerBlack)), style: {
            backgroundColor: 
            // set background color for letters and nothing to board color
            !backgroundColor || props.code === 0 || (characterCode === null || characterCode === void 0 ? void 0 : characterCode.sprite)
                ? props.boardStyle === 'white'
                    ? '#ececec'
                    : '#2c2c2c'
                : backgroundColor,
        } },
        React.createElement("input", { disabled: props.disabled, ref: bitRef, style: __assign(__assign({ cursor: props.mode === 'paint' ? 'default' : undefined }, classes.input), (props.boardStyle === 'white'
                ? classes.inputLight
                : classes.inputDark)), value: value, onChange: function (e) {
                _changeEvent = e.target.value;
            }, onMouseDown: function () {
                props.startPainting();
                if (props.mode === 'paint') {
                    props.onPaint();
                }
            }, onMouseEnter: function () {
                if (props.mode === 'paint') {
                    props.onPaint();
                }
            }, onTouchStart: function () {
                props.startPainting();
                if (props.mode === 'paint') {
                    props.onPaint();
                }
            }, onKeyUp: function (e) {
                var intl = getInternationalKey(e);
                props.onKeyPress({
                    shiftKey: intl ? intl.shiftKey : e.shiftKey,
                    bitKey: props.bitKey,
                    rowKey: props.rowKey,
                    keyCode: intl
                        ? intl.keyCode
                        : (e.keyCode === 229
                            ? _changeEvent === null || _changeEvent === void 0 ? void 0 : _changeEvent.charCodeAt(0)
                            : e.keyCode),
                });
            } })));
};
