var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { Bit } from './Bit';
import { Box } from '@mui/material';
import React, { useEffect, useRef } from 'react';
import { selectDown, selectLeft, selectRight, selectUp, setBitValue as setBitValueFn, } from './controls';
import MattBlackImage from '../../assets/vestaboard-matte-black.png';
import MattWhiteImage from '../../assets/vestaboard-matte-white.png';
import { getBitByKeyCode } from '../../utils/getBitByKeyCode';
import { makeVestaboardStyles } from '../../hooks/useVestaboardStyles';
import { responsive } from '../../theme';
import useMediaQuery from '@mui/material/useMediaQuery';
var useStyles = makeVestaboardStyles({
    container: {
        position: 'relative',
        width: '100%',
        paddingTop: '53.4%',
        backgroundColor: '#303030',
        backgroundSize: 'contain',
    },
    containerWhite: {
        backgroundImage: "url(".concat(MattWhiteImage, ")"),
    },
    containerBlack: {
        backgroundImage: "url(".concat(MattBlackImage, ")"),
    },
    containerBlackNonStandard: {
        backgroundColor: '#262727',
    },
    containerWhiteNonStandard: {
        backgroundColor: '#d8d9d8',
    },
    mobilePaintContainer: {
        marginTop: '14px',
        position: 'relative',
        width: '100%',
        paddingTop: '40%',
    },
    bits: {
        position: 'absolute',
        width: '90%',
        height: '78%',
        top: '11%',
        left: '5%',
        justifyContent: 'space-between',
        display: 'flex',
        flexDirection: 'column',
    },
    mobilePaintBits: {
        position: 'absolute',
        width: '100%',
        height: '100%',
        top: '0px',
        left: '0px',
        justifyContent: 'space-between',
        display: 'flex',
        flexDirection: 'column',
    },
    bitRow: {
        width: '100%',
        height: '13%',
        display: 'flex',
        justifyContent: 'space-between',
        '&:first-child': {
            marginTop: 0,
        },
    },
    mobilePaintBitRow: {
        width: '100%',
        height: '15%',
        display: 'flex',
        justifyContent: 'space-between',
        '&:first-child': {
            marginTop: 0,
        },
    },
    splitterVertical: {
        width: '100%',
        position: 'absolute',
        top: '50%',
        left: '0%',
        height: 1,
        backgroundImage: 'linear-gradient(to right, #f5f5f7 10%, rgba(255, 255, 255, 0) 0%)',
        backgroundPosition: 'top',
        backgroundSize: '10px 1px',
        backgroundRepeat: 'repeat-x',
        opacity: 0.5,
    },
    splitterHorizontal: {
        height: '140%',
        position: 'absolute',
        left: 'calc(50% - 3px)',
        top: '-20%',
        width: 1,
        backgroundImage: 'linear-gradient(to bottom, #f5f5f7 10%, rgba(255, 255, 255, 0) 0%)',
        backgroundPosition: 'left',
        backgroundSize: '1px 10px',
        backgroundRepeat: 'repeat-y',
        opacity: 0.5,
    },
});
export var Board = function (props) {
    var classes = useStyles();
    var boardRef = useRef(null);
    var paintingRef = useRef(false);
    var setBitValue = setBitValueFn({
        value: props.value,
        setValue: props.setValue,
    });
    var isMobile = useMediaQuery("(max-width: ".concat(responsive.MOBILE, "px)"));
    // Mobile Painting
    useEffect(function () {
        var handleTouchMove = function (e) {
            var _a;
            if (props.mode === 'paint') {
                var _b = e.touches[0], clientX_1 = _b.clientX, clientY_1 = _b.clientY;
                var boardRefs_1 = [];
                (_a = boardRef === null || boardRef === void 0 ? void 0 : boardRef.current) === null || _a === void 0 ? void 0 : _a.querySelectorAll('.bit-row').forEach(function (row, rowIndex) {
                    row.querySelectorAll('input').forEach(function (bitRef, bitIndex) {
                        boardRefs_1.push({
                            bitRef: bitRef,
                            rowIndex: rowIndex,
                            bitIndex: bitIndex,
                        });
                    });
                });
                boardRefs_1.forEach(function (current) {
                    var el = current.bitRef;
                    var rect = el.getBoundingClientRect();
                    if (rect.top < clientY_1 &&
                        rect.bottom > clientY_1 &&
                        rect.left < clientX_1 &&
                        rect.right > clientX_1) {
                        setBitValue(current.rowIndex, current.bitIndex, props.color || 0);
                    }
                });
            }
        };
        document.addEventListener('touchmove', handleTouchMove);
        return function () {
            document.removeEventListener('touchmove', handleTouchMove);
        };
    }, [props.mode, props.value]);
    // Desktop painting
    useEffect(function () {
        var handleMouseRelease = function () {
            if (props.mode === 'paint') {
                paintingRef.current = false;
            }
        };
        document.addEventListener('mouseup', handleMouseRelease);
        return function () {
            document.removeEventListener('mouseup', handleMouseRelease);
        };
    }, [props.mode]);
    var onKeyPress = function (_a) {
        var rowKey = _a.rowKey, bitKey = _a.bitKey, keyCode = _a.keyCode, shiftKey = _a.shiftKey;
        if (!props.setValue) {
            return;
        }
        if (keyCode === 9 || // Tab
            keyCode === 16 ||
            keyCode === 17 ||
            keyCode === 18 ||
            keyCode === 35 ||
            keyCode === 45 ||
            keyCode === 144 ||
            keyCode === 166 ||
            keyCode === 167) {
            return;
        }
        // navigation keys
        if (keyCode === 38) {
            return selectUp(boardRef)(rowKey, bitKey);
        }
        else if (keyCode === 40) {
            return selectDown(boardRef)(rowKey, bitKey);
        }
        else if (keyCode === 37) {
            return selectLeft(boardRef)(rowKey, bitKey);
        }
        else if (keyCode === 39) {
            return selectRight(boardRef)(rowKey, bitKey);
        }
        // Enter key
        if (keyCode === 13) {
            return selectDown(boardRef)(rowKey, bitKey);
        }
        // Backspace or delete
        if (keyCode === 8 || keyCode === 46) {
            setBitValue(rowKey, bitKey, 0);
            return selectLeft(boardRef)(rowKey, bitKey);
        }
        // Bit Code Characters
        var bitCode = getBitByKeyCode(keyCode, shiftKey);
        if (bitCode !== null) {
            setBitValue(rowKey, bitKey, bitCode);
            return selectRight(boardRef)(rowKey, bitKey);
        }
    };
    var isMobilePaintMode = isMobile && props.mode !== 'preview';
    return (React.createElement(Box, { sx: isMobilePaintMode
            ? classes.mobilePaintContainer
            : __assign(__assign(__assign({}, classes.container), ((props.rows === 6 || !props.rows) &&
                (props.columns === 22 || !props.columns)
                ? props.boardStyle === 'white'
                    ? classes.containerWhite
                    : classes.containerBlack
                : props.boardStyle === 'white'
                    ? classes.containerWhiteNonStandard
                    : classes.containerBlackNonStandard)), {
                paddingTop: "".concat((53.4 / (((props === null || props === void 0 ? void 0 : props.columns) || 22) / ((props === null || props === void 0 ? void 0 : props.rows) || 6))) *
                    (22 / 6), "%"),
            }) },
        isMobilePaintMode ? React.createElement(Box, { sx: classes.splitterVertical }) : null,
        isMobilePaintMode ? React.createElement(Box, { sx: classes.splitterHorizontal }) : null,
        React.createElement("div", { style: isMobilePaintMode
                ? classes.mobilePaintBits
                : classes.bits, ref: boardRef }, props.value.map(function (bitRow, rowKey) { return (React.createElement(Box, { key: rowKey, className: 'bit-row', sx: __assign(__assign({}, (isMobilePaintMode
                ? classes.mobilePaintBitRow
                : classes.bitRow)), { height: "".concat((12.9 / ((props === null || props === void 0 ? void 0 : props.rows) || 6)) * 6, "%") }) }, bitRow.map(function (code, bitKey) { return (React.createElement(Bit, { key: bitKey, code: code, rowKey: rowKey, bitKey: bitKey, onKeyPress: onKeyPress, animated: props.animated, disabled: props.mode === 'display', mode: props.mode, boardStyle: props.boardStyle, startPainting: function () {
                if (props.mode === 'paint') {
                    paintingRef.current = true;
                }
            }, onPaint: function () {
                if (paintingRef.current) {
                    setBitValue(rowKey, bitKey, props.color || 0);
                }
            } })); }))); }))));
};
