import { useCallback } from 'react';
/**
 * _useUpdateDetails_
 *
 * Posts updates to Installable details i.e.(title and icon url) to the React Native app's WebView component
 * iconUrl via the window `postMessage()` method.
 *
 * @example
 *
 * ```tsx
 *
 * import { useUpdateDetails } from '@vestaboard/installable-kit/hooks'
 *
 * const { updateDetails } = useUpdateDetails()
 *
 * updateDetails('New Title')
 *
 * ```
 *
 * @see https://developer.mozilla.org/en-US/docs/Web/API/Window/postMessage
 */
export var useUpdateDetails = function () {
    var updateTitle = useCallback(function (_a) {
        var title = _a.title, iconUrl = _a.iconUrl, subscriptionId = _a.subscriptionId;
        try {
            var anyWindow = window;
            var data = JSON.stringify({
                topic: 'details',
                subscriptionId: subscriptionId,
                title: title,
                iconUrl: iconUrl,
            });
            // For React Native WebView, post to the WebView
            if (anyWindow === null || anyWindow === void 0 ? void 0 : anyWindow.ReactNativeWebView) {
                anyWindow === null || anyWindow === void 0 ? void 0 : anyWindow.ReactNativeWebView.postMessage(data);
                // For IFrames, post to the parent window
            }
            else if (window === null || window === void 0 ? void 0 : window.parent) {
                window.parent.postMessage(data, '*');
            }
        }
        catch (error) {
            console.error(error);
        }
        return null;
    }, []);
    return {
        updateTitle: updateTitle,
    };
};
